@@ -121,9 +121,8 @@ sub execute {
     gcr_change_state($commit,'locked', { skip => 'true', message => 'Locked.' });
 
     # Only show "move" unless we have > 1 profile
-    my %profiles = gcr_profiles();
-    my $profiles = scalar(keys %profiles);
-    delete $LABELS{move} unless $profiles > 1;
+    my @profiles = gcr_profiles();
+    delete $LABELS{move} unless @profiles > 1;
 
     # Show the Commit
     my $action ='_view';
@@ -222,8 +221,8 @@ sub move {
     my ($commit) = @_;
     verbose("+ Moving $commit->{base}");
 
-    my %profiles = gcr_profiles();
-    my $to = prompt("Which profile are you moving this commit to?", menu => [sort keys %profiles]);
+    my $profiles = gcr_profiles();
+    my $to = prompt("Which profile are you moving this commit to?", menu => $profiles);
     my $details = prompt("Why are you moving this to $to: ", validate => { "Really, not even 10 characters? " => sub { length $_ > 10; } });
 
     gcr_change_profile($commit,$to,$details);
@@ -243,7 +242,7 @@ Git::Code::Review::Command::pick - Allows reviewers to select a commit for audit
 
 =head1 VERSION
 
-version 0.9
+version 1.0
 
 =head1 AUTHOR
 
